This is the mail archive of the glibc-cvs@sourceware.org mailing list for the glibc project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

GNU C Library master sources branch, hjl/pr14117, updated. glibc-2.15-1100-gbe681f0


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU C Library master sources".

The branch, hjl/pr14117 has been updated
       via  be681f045c95de1b8aa6ea2410a3c980f4a2d305 (commit)
      from  4c7c46b43e54556afafbafd465cb89e0f0787044 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://sources.redhat.com/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=be681f045c95de1b8aa6ea2410a3c980f4a2d305

commit be681f045c95de1b8aa6ea2410a3c980f4a2d305
Author: H.J. Lu <hjl.tools@gmail.com>
Date:   Wed May 30 17:42:42 2012 -0700

    Check __SSE_MATH__ instead of __x86_64__

diff --git a/ChangeLog.fpu b/ChangeLog.fpu
index eed5135..a3c7592 100644
--- a/ChangeLog.fpu
+++ b/ChangeLog.fpu
@@ -1,5 +1,10 @@
 2012-05-30  H.J. Lu  <hongjiu.lu@intel.com>
 
+	* sysdeps/x86/fpu/bits/mathinline.h: Check __SSE_MATH__
+	instead of __x86_64__.
+
+2012-05-30  H.J. Lu  <hongjiu.lu@intel.com>
+
 	[BZ #14117]
 	* sysdeps/i386/fpu/bits/fenv.h: Removed.
 	* sysdeps/i386/fpu/bits/mathinline.h: Likewise.
diff --git a/sysdeps/x86/fpu/bits/mathinline.h b/sysdeps/x86/fpu/bits/mathinline.h
index a4e6df8..7919d1e 100644
--- a/sysdeps/x86/fpu/bits/mathinline.h
+++ b/sysdeps/x86/fpu/bits/mathinline.h
@@ -382,8 +382,8 @@ __END_NAMESPACE_C99
 # endif
 
 # if ((!defined __NO_MATH_INLINES || defined __LIBC_INTERNAL_MATH_INLINES) \
-     && !defined __x86_64__ && defined __OPTIMIZE__)
-/* Not used for x86-64.  */
+     && !defined __SSE_MATH__ && defined __OPTIMIZE__)
+/* Not used by SSE math.  */
 
 /* The inline functions do not set errno or raise necessarily the
    correct exceptions.  */
@@ -521,8 +521,8 @@ __END_NAMESPACE_C99
 # endif
 
 
 # if !defined __x86_64__ && !defined __NO_MATH_INLINES && defined __OPTIMIZE__
 /* Miscellaneous functions.  Not used by x86-64.   */
 
 /* __FAST_MATH__ is defined by gcc -ffast-math.  */
 #  ifdef __FAST_MATH__
@@ -953,8 +953,8 @@ __NTH (__finite (double __x))
 # endif /* __NO_MATH_INLINES  */
 
 
 /* This code is used internally in the GNU libc.  Not used by x86-64.  */
 # if !defined __x86_64__ && defined __LIBC_INTERNAL_MATH_INLINES
 __inline_mathop (__ieee754_sqrt, "fsqrt")
 __inline_mathcode2 (__ieee754_atan2, __y, __x,
 		    register long double __value;

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog.fpu                     |    5 +++++
@@ -521,8 +521,8 @@ __END_NAMESPACE_C99
 
 
-# if !defined __x86_64__ && !defined __NO_MATH_INLINES && defined __OPTIMIZE__
-/* Miscellaneous functions.  Not used by x86-64.   */
+# if !defined __SSE_MATH__ && !defined __NO_MATH_INLINES && defined __OPTIMIZE__
+/* Miscellaneous functions.  Not used by SSE math.   */
 
 /* __FAST_MATH__ is defined by gcc -ffast-math.  */
@@ -953,8 +953,8 @@ __NTH (__finite (double __x))
 
 
-/* This code is used internally in the GNU libc.  Not used by x86-64.  */
-# if !defined __x86_64__ && defined __LIBC_INTERNAL_MATH_INLINES
+/* This code is used internally in the GNU libc.  Not used by SSE math.  */
+# if !defined __SSE_MATH__ && defined __LIBC_INTERNAL_MATH_INLINES
 __inline_mathop (__ieee754_sqrt, "fsqrt")
 __inline_mathcode2 (__ieee754_atan2, __y, __x,
 sysdeps/x86/fpu/bits/mathinline.h |   12 ++++++------
 2 files changed, 11 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
GNU C Library master sources


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]